==> owncloud-8.2.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/da.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Server til serverdeling er ikke slået til på denne server",
    "The mountpoint name contains invalid characters." : "Monteringspunktets navn indeholder ugyldige tegn.",
    "Invalid or untrusted SSL certificate" : "Ugyldigt eller upålideligt SSL-certifikat",
    "Could not authenticate to remote share, password might be wrong" : "Kunne ikke godkende fjerndelingen - kodeordet er muilgvis forkert",
    "Storage not valid" : "Lagerplads er ikke gyldig",
    "Couldn't add remote share" : "Kunne ikke tliføje den ekstern deling",
    "Shared with you" : "Delt med dig",
    "Shared with others" : "Delt med andre",
    "Shared by link" : "Delt via link",
    "Nothing shared with you yet" : "Der deles ikke noget med dig endnu",
    "Files and folders others share with you will show up here" : "Filer og mapper som andre deler med dig, vil blive vist her",
    "Nothing shared yet" : "Der deles endnu ikke noget",
    "Files and folders you share will show up here" : "Filer og mapper som du deler, vil blive vist her",
    "No shared links" : "Ingen delte link",
    "Files and folders you share by link will show up here" : "Filer og mapper som du deler gennem link, vil blive vist her",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Vil du tilføje den eksterne deling {name} fra {owner}@{remote}?",
    "Remote share" : "Ekstern deling",
    "Remote share password" : "Adgangskode for ekstern deling",
    "Cancel" : "Annuller",
    "Add remote share" : "Tilføj ekstern deling",
    "You can upload into this folder" : "Du kan overføre til denne mappe",
    "No ownCloud installation (7 or higher) found at {remote}" : "Der er ingen ownCloud-installation (7 eller højere) på {remote}",
    "Invalid ownCloud url" : "Ugyldig ownCloud-URL",
    "Shared by" : "Delt af",
    "Sharing" : "Deling",
    "A file or folder has been <strong>shared</strong>" : "En fil eller mappe er blevet <strong>delt</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "En fil eller mappe blev delt fra <strong>en anden server</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "En offentligt delt fil eller mappe blev <strong>hentet</strong>",
    "You received a new remote share %2$s from %1$s" : "Du modtog en ny ekstern deling %2$s fra %1$s",
    "You received a new remote share from %s" : "Du modtog en ny ekstern deling fra %s",
    "%1$s accepted remote share %2$s" : "%1$s accepterede den ekstern deling %2$s",
    "%1$s declined remote share %2$s" : "%1$s afviste den eksterne deling %2$s",
    "%1$s unshared %2$s from you" : "%1$s stoppede med at dele %2$s med dig",
    "Public shared folder %1$s was downloaded" : "Den offentligt delte mappe %1$s blev downloadet",
    "Public shared file %1$s was downloaded" : "Den offentligt delte fil %1$s blev downloadet",
    "You shared %1$s with %2$s" : "Du delte %1$s med %2$s",
    "You shared %1$s with group %2$s" : "Du delte %1$s med gruppen %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s delt %1$s med %3$s",
    "%2$s shared %1$s with group %3$s" : "%2$s delt %1$s med gruppen %3$s",
    "%2$s shared %1$s via link" : "%2$s delt %1$s via link",
    "%2$s shared %1$s with you" : "%2$s delt %1$s med dig",
    "You shared %1$s via link" : "Du delte %1$s via link",
    "Shares" : "Delt",
    "You received %2$s as a remote share from %1$s" : "Du modtog %2$s som en ekstern deling fra %1$s",
    "Accept" : "Acceptér",
    "Decline" : "Afvis",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Del med mig gennem min #ownCloud Federated Cloud ID, se %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Del med mig gennem min #ownCloud Federated Cloud ID",
    "This share is password-protected" : "Delingen er beskyttet af kodeord",
    "The password is wrong. Try again." : "Kodeordet er forkert. Prøv igen.",
    "Password" : "Kodeord",
    "No entries found in this folder" : "Der blev ikke fundet poster i denne mappe",
    "Name" : "Navn",
    "Share time" : "Dele periode",
    "Sorry, this link doesn’t seem to work anymore." : "Desværre, dette link ser ikke ud til at fungerer længere.",
    "Reasons might be:" : "Årsagen kan være:",
    "the item was removed" : "Filen blev fjernet",
    "the link expired" : "linket udløb",
    "sharing is disabled" : "deling er deaktiveret",
    "For more info, please ask the person who sent this link." : "For yderligere information, kontakt venligst personen der sendte linket. ",
    "Add to your ownCloud" : "Tilføj til din ownCload",
    "Download" : "Hent",
    "Download %s" : "Hent %s",
    "Direct link" : "Direkte link",
    "Federated Cloud Sharing" : "Sammensluttet Cloud deling",
    "Open documentation" : "Åben dokumentation",
    "Allow users on this server to send shares to other servers" : "Tillad brugere på denne server, at sende delinger til andre servere",
    "Allow users on this server to receive shares from other servers" : "Tillad brugere på denne server, at modtage delinger fra andre servere",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Din Federated Cloud ID:",
    "Share it:" : "Del:",
    "Add to your website" : "Tilføj til dit websted",
    "Share with me via ownCloud" : "Del med mig gennem ownCloud",
    "HTML Code:" : "HTMLkode:"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_sharing/l10n/da.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Server til serverdeling er ikke slået til på denne server",
    "The mountpoint name contains invalid characters." : "Monteringspunktets navn indeholder ugyldige tegn.",
    "Invalid or untrusted SSL certificate" : "Ugyldigt eller upålideligt SSL-certifikat",
    "Could not authenticate to remote share, password might be wrong" : "Kunne ikke godkende fjerndelingen - kodeordet er muilgvis forkert",
    "Storage not valid" : "Lagerplads er ikke gyldig",
    "Couldn't add remote share" : "Kunne ikke tliføje den ekstern deling",
    "Shared with you" : "Delt med dig",
    "Shared with others" : "Delt med andre",
    "Shared by link" : "Delt via link",
    "Nothing shared with you yet" : "Der deles ikke noget med dig endnu",
    "Files and folders others share with you will show up here" : "Filer og mapper som andre deler med dig, vil blive vist her",
    "Nothing shared yet" : "Der deles endnu ikke noget",
    "Files and folders you share will show up here" : "Filer og mapper som du deler, vil blive vist her",
    "No shared links" : "Ingen delte link",
    "Files and folders you share by link will show up here" : "Filer og mapper som du deler gennem link, vil blive vist her",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Vil du tilføje den eksterne deling {name} fra {owner}@{remote}?",
    "Remote share" : "Ekstern deling",
    "Remote share password" : "Adgangskode for ekstern deling",
    "Cancel" : "Annuller",
    "Add remote share" : "Tilføj ekstern deling",
    "You can upload into this folder" : "Du kan overføre til denne mappe",
    "No ownCloud installation (7 or higher) found at {remote}" : "Der er ingen ownCloud-installation (7 eller højere) på {remote}",
    "Invalid ownCloud url" : "Ugyldig ownCloud-URL",
    "Shared by" : "Delt af",
    "Sharing" : "Deling",
    "A file or folder has been <strong>shared</strong>" : "En fil eller mappe er blevet <strong>delt</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "En fil eller mappe blev delt fra <strong>en anden server</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "En offentligt delt fil eller mappe blev <strong>hentet</strong>",
    "You received a new remote share %2$s from %1$s" : "Du modtog en ny ekstern deling %2$s fra %1$s",
    "You received a new remote share from %s" : "Du modtog en ny ekstern deling fra %s",
    "%1$s accepted remote share %2$s" : "%1$s accepterede den ekstern deling %2$s",
    "%1$s declined remote share %2$s" : "%1$s afviste den eksterne deling %2$s",
    "%1$s unshared %2$s from you" : "%1$s stoppede med at dele %2$s med dig",
    "Public shared folder %1$s was downloaded" : "Den offentligt delte mappe %1$s blev downloadet",
    "Public shared file %1$s was downloaded" : "Den offentligt delte fil %1$s blev downloadet",
    "You shared %1$s with %2$s" : "Du delte %1$s med %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s delt %1$s med %3$s",
    "You shared %1$s with group %2$s" : "Du delte %1$s med gruppen %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s delt %1$s med gruppen %3$s",
    "%2$s shared %1$s via link" : "%2$s delt %1$s via link",
    "You shared %1$s via link" : "Du delte %1$s via link",
    "%2$s shared %1$s with you" : "%2$s delt %1$s med dig",
    "Downloaded via public link" : "Downloaded via et offentligt link",
    "Shared with %2$s" : "Delt med %2$s",
    "Shared with %3$s by %2$s" : "Delt med %3$s af %2$s",
    "Shared with group %2$s" : "Delt med gruppen %2$s",
    "Shared with group %3$s by %2$s" : "Delt med gruppen %3$s af %2$s",
    "Shared via link by %2$s" : "Delt via link af %2$s",
    "Shared via public link" : "Delt via offentligt link",
    "Shared by %2$s" : "Delt af %2$s",
    "Shares" : "Delt",
    "Accept" : "Acceptér",
    "Decline" : "Afvis",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Del med mig gennem min #ownCloud Federated Cloud ID, se %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Del med mig gennem min #ownCloud Federated Cloud ID",
    "This share is password-protected" : "Delingen er beskyttet af kodeord",
    "The password is wrong. Try again." : "Kodeordet er forkert. Prøv igen.",
    "Password" : "Kodeord",
    "No entries found in this folder" : "Der blev ikke fundet poster i denne mappe",
    "Name" : "Navn",
    "Share time" : "Dele periode",
    "Sorry, this link doesn’t seem to work anymore." : "Desværre, dette link ser ikke ud til at fungerer længere.",
    "Reasons might be:" : "Årsagen kan være:",
    "the item was removed" : "Filen blev fjernet",
    "the link expired" : "linket udløb",
    "sharing is disabled" : "deling er deaktiveret",
    "For more info, please ask the person who sent this link." : "For yderligere information, kontakt venligst personen der sendte linket. ",
    "Add to your ownCloud" : "Tilføj til din ownCload",
    "Download" : "Hent",
    "Download %s" : "Hent %s",
    "Direct link" : "Direkte link",
    "Federated Cloud Sharing" : "Sammensluttet Cloud deling",
    "Open documentation" : "Åben dokumentation",
    "Allow users on this server to send shares to other servers" : "Tillad brugere på denne server, at sende delinger til andre servere",
    "Allow users on this server to receive shares from other servers" : "Tillad brugere på denne server, at modtage delinger fra andre servere",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Din Federated Cloud ID:",
    "Share it:" : "Del:",
    "Add to your website" : "Tilføj til dit websted",
    "Share with me via ownCloud" : "Del med mig gennem ownCloud",
    "HTML Code:" : "HTMLkode:",
    "Public shared file %1$s was downloaded" : "Den offentligt delte fil %1$s blev downloadet",
    "Public shared folder %1$s was downloaded" : "Den offentligt delte mappe %1$s blev downloadet",
    "Shared by %2$s" : "Delt af %2$s",
    "Shared via link by %2$s" : "Delt via link af %2$s",
    "Shared with group %3$s by %2$s" : "Delt med gruppen %3$s af %2$s"
},
"nplurals=2; plural=(n != 1);");
